#ifndef _TKCONFIG
#define _TKCONFIG
#define ANSI_SIGNED_CHAR 1
#define CAN_COPSTASH_SET_NULL 1
#define HAS_SVIV_NOMG 1
#define HAS_SVNV_NOMG 1
#define HAVE_INTTYPES_H 1
#define HAVE_LIMITS_H 1
#define HAVE_SYS_SELECT_H 1
#define HAVE_SYS_TIME_H 1
#define HAVE_UNISTD_H 1
#define NOCONST 1
#define SELECT_MASK fd_set
#define TIMEOFDAY_TZ 1
#define TIME_WITH_SYS_TIME 1
#define USE_NEWSTYLE_REGEXP_STRUCT 1
#define USE_PREGCOMP_31027 1
#define USE_PROTOTYPE 1
#define USE_REGEXP_511 1
#endif
